@@ -2,35 +2,36 @@
 # this repository contains the full copyright notices and license terms.
 import csv
 import unicodedata
-from io import BytesIO, TextIOWrapper
-
 from collections import defaultdict
-from dateutil.relativedelta import relativedelta
 from decimal import Decimal
+from io import BytesIO, TextIOWrapper
 from operator import attrgetter
 
-from sql import Cast, Null, Literal
+import phonenumbers
+from dateutil.relativedelta import relativedelta
+# XXX fix: https://genshi.edgewall.org/ticket/582
+from genshi.template.astutil import ASTCodeGenerator, ASTTransformer
+from phonenumbers import NumberParseException
+from sql import Cast, Literal, Null
 from sql.aggregate import Count, Min, Sum
 from sql.conditionals import Case, Coalesce
-from sql.functions import Substring, Position, Extract, CurrentTimestamp
+from sql.functions import CurrentTimestamp, Extract, Position, Substring
 from sql.operators import Exists
 
 from trytond.i18n import gettext
 from trytond.model import ModelSQL, ModelView, fields
 from trytond.model.modelsql import convert_from
+from trytond.modules.account_eu.account import ECSalesList, ECSalesListContext
+from trytond.modules.currency.fields import Monetary
 from trytond.pool import Pool
 from trytond.pyson import Eval, If
 from trytond.report import Report
 from trytond.transaction import Transaction
-from trytond.wizard import Wizard, StateView, StateTransition, StateReport, \
-    Button
-from trytond.modules.account_eu.account import ECSalesList, ECSalesListContext
-from trytond.modules.currency.fields import Monetary
+from trytond.wizard import (
+    Button, StateReport, StateTransition, StateView, Wizard)
 
 from .exceptions import PrintError
 
-# XXX fix: https://genshi.edgewall.org/ticket/582
-from genshi.template.astutil import ASTCodeGenerator, ASTTransformer
 if not hasattr(ASTCodeGenerator, 'visit_NameConstant'):
     def visit_NameConstant(self, node):
         if node.value is None:
@@ -69,6 +70,17 @@ def format_percentage(n, size=5):
     return ('{0:.2f}'.format(n)).replace('.', '').rjust(size, '0')
 
 
+def format_phone(phone):
+    try:
+        phone = phonenumbers.format_number(
+            phonenumbers.parse(phone, 'ES'),
+            phonenumbers.PhoneNumberFormat.NATIONAL)
+    except NumberParseException:
+        phone = ''
+    phone = phone.replace(' ', '')
+    return phone[:9].rjust(9, '0')
+
+
 def identifier_code(identifier):
     if identifier:
         return identifier.es_code()
@@ -544,6 +556,7 @@ class AEAT347(Report):
                 15, '0')
         context['format_decimal'] = format_decimal
         context['format_integer'] = format_integer
+        context['format_phone'] = format_phone
         context['identifier_code'] = identifier_code
         context['country_code'] = country_code
         context['strip_accents'] = strip_accents
@@ -633,16 +646,14 @@ class ECOperationListContext(ECSalesListContext):
                 ('start_date', '<=', Eval('end_date')),
                 (),
                 ),
-            ],
-        depends=['end_date'])
+            ])
     end_date = fields.Date("End Date",
         domain=[
             If(Eval('start_date'),
                 ('end_date', '>=', Eval('start_date')),
                 (),
                 ),
-            ],
-        depends=['start_date'])
+            ])
 
     @classmethod
     def default_start_date(cls):
@@ -702,6 +713,7 @@ class AEAT349(Report):
             return ('{0:.2f}'.format(abs(n))).replace('.', '').rjust(
                 digits, '0')
         context['format_decimal'] = format_decimal
+        context['format_phone'] = format_phone
 
         return context
 
@@ -715,19 +727,17 @@ class ESVATBookContext(ModelView):
         required=True,
         domain=[
             ('company', '=', Eval('company')),
-            ],
-        depends=['company'])
+            ])
     start_period = fields.Many2One('account.period', "Start Period",
         domain=[
             ('fiscalyear', '=', Eval('fiscalyear')),
             ('start_date', '<=', (Eval('end_period'), 'start_date')),
-            ], depends=['fiscalyear', 'end_period'])
+            ])
     end_period = fields.Many2One('account.period', "End Period",
         domain=[
             ('fiscalyear', '=', Eval('fiscalyear')),
             ('start_date', '>=', (Eval('start_period'), 'start_date'))
-            ],
-        depends=['fiscalyear', 'start_period'])
+            ])
     es_vat_book_type = fields.Selection([
             # Use same key as tax authority
             ('E', "Issued"),
@@ -770,8 +780,7 @@ class ESVATBook(ModelSQL, ModelView):
         "Surcharge Tax Amount", currency='currency', digits='currency',
         states={
             'invisible': ~(Eval('surcharge_tax', None)),
-            },
-        depends=['surcharge_tax'])
+            })
 
     currency = fields.Function(fields.Many2One(
             'currency.currency', "Currency"),
